Module error

Module error 

Structs

LazyPlanContext
PlanExecutionError
The central error type for all query plan execution failures.
PlanExecutionErrorContext

Enums

PlanExecutionErrorKind

Traits

IntoPlanExecutionError
An extension trait for Result types that can be converted into a PlanExecutionError.