pub struct PlanExecutionOutput {
pub body: Vec<u8>,
pub response_headers_aggregator: Option<ResponseHeaderAggregator>,
pub error_count: usize,
pub status_code: StatusCode,
}Fields
body: Vec<u8>response_headers_aggregator: Option<ResponseHeaderAggregator>error_count: usizestatus_code: StatusCodeTrait Implementations
Sourceimpl Default for PlanExecutionOutput
impl Default for PlanExecutionOutput
Sourcefn default() -> PlanExecutionOutput
fn default() -> PlanExecutionOutput
Returns the “default value” for a type. Read more
Sourceimpl<'exec> EndHookPayload<PlanExecutionOutput> for OnExecuteEndHookPayload<'exec>
impl<'exec> EndHookPayload<PlanExecutionOutput> for OnExecuteEndHookPayload<'exec>
Sourcefn proceed(self) -> EndHookResult<Self, TResponse>
fn proceed(self) -> EndHookResult<Self, TResponse>
Continue with the regular flow of the hook
This is called in most cases when you don’t short-circuit the hook with a response or an error.
Sourcefn end_with_response(self, output: TResponse) -> EndHookResult<Self, TResponse>
fn end_with_response(self, output: TResponse) -> EndHookResult<Self, TResponse>
End the hook execution and return a response to the client immediately, skipping the rest of the execution flow.
Sourcefn end_with_graphql_error(
self,
error: GraphQLError,
status_code: StatusCode,
) -> EndHookResult<Self, TResponse>
fn end_with_graphql_error( self, error: GraphQLError, status_code: StatusCode, ) -> EndHookResult<Self, TResponse>
End the hook execution with a GraphQL error,
returning a response with the appropriate error format to the client immediately, skipping the rest of the execution flow. Read more
Sourceimpl EndHookPayload<PlanExecutionOutput> for OnQueryPlanEndHookPayload
impl EndHookPayload<PlanExecutionOutput> for OnQueryPlanEndHookPayload
Sourcefn proceed(self) -> EndHookResult<Self, TResponse>
fn proceed(self) -> EndHookResult<Self, TResponse>
Continue with the regular flow of the hook
This is called in most cases when you don’t short-circuit the hook with a response or an error.
Sourcefn end_with_response(self, output: TResponse) -> EndHookResult<Self, TResponse>
fn end_with_response(self, output: TResponse) -> EndHookResult<Self, TResponse>
End the hook execution and return a response to the client immediately, skipping the rest of the execution flow.
Sourcefn end_with_graphql_error(
self,
error: GraphQLError,
status_code: StatusCode,
) -> EndHookResult<Self, TResponse>
fn end_with_graphql_error( self, error: GraphQLError, status_code: StatusCode, ) -> EndHookResult<Self, TResponse>
End the hook execution with a GraphQL error,
returning a response with the appropriate error format to the client immediately, skipping the rest of the execution flow. Read more
Sourceimpl FromGraphQLErrorToResponse for PlanExecutionOutput
impl FromGraphQLErrorToResponse for PlanExecutionOutput
fn from_graphql_error_to_response( error: GraphQLError, status_code: StatusCode, ) -> Self
Sourceimpl<'exec> StartHookPayload<OnExecuteEndHookPayload<'exec>, PlanExecutionOutput> for OnExecuteStartHookPayload<'exec>
impl<'exec> StartHookPayload<OnExecuteEndHookPayload<'exec>, PlanExecutionOutput> for OnExecuteStartHookPayload<'exec>
Sourcefn proceed<'exec>(self) -> StartHookResult<'exec, Self, TEndPayload, TResponse>
fn proceed<'exec>(self) -> StartHookResult<'exec, Self, TEndPayload, TResponse>
Continue with the regular flow of the hook
This is called in most cases when you don’t short-circuit the hook with a response or an error. Read more
Sourcefn end_with_response<'exec>(
self,
output: TResponse,
) -> StartHookResult<'exec, Self, TEndPayload, TResponse>
fn end_with_response<'exec>( self, output: TResponse, ) -> StartHookResult<'exec, Self, TEndPayload, TResponse>
End the hook execution and return a response to the client immediately, skipping the rest of the execution flow.
Sourcefn end_with_graphql_error<'exec>(
self,
error: GraphQLError,
status_code: StatusCode,
) -> StartHookResult<'exec, Self, TEndPayload, TResponse>where
TResponse: FromGraphQLErrorToResponse,
fn end_with_graphql_error<'exec>(
self,
error: GraphQLError,
status_code: StatusCode,
) -> StartHookResult<'exec, Self, TEndPayload, TResponse>where
TResponse: FromGraphQLErrorToResponse,
End the hook execution with a GraphQL error,
returning a response with the appropriate error format to the client immediately, skipping the rest of the execution flow. Read more
Sourcefn on_end<'exec, F>(
self,
f: F,
) -> StartHookResult<'exec, Self, TEndPayload, TResponse>
fn on_end<'exec, F>( self, f: F, ) -> StartHookResult<'exec, Self, TEndPayload, TResponse>
Attach a callback to be executed at the end of the hook, allowing you to manipulate the end payload or response.
This is useful when you want to execute some logic after the main execution of the hook Read more
Sourceimpl<'exec> StartHookPayload<OnQueryPlanEndHookPayload, PlanExecutionOutput> for OnQueryPlanStartHookPayload<'exec>
impl<'exec> StartHookPayload<OnQueryPlanEndHookPayload, PlanExecutionOutput> for OnQueryPlanStartHookPayload<'exec>
Sourcefn proceed<'exec>(self) -> StartHookResult<'exec, Self, TEndPayload, TResponse>
fn proceed<'exec>(self) -> StartHookResult<'exec, Self, TEndPayload, TResponse>
Continue with the regular flow of the hook
This is called in most cases when you don’t short-circuit the hook with a response or an error. Read more
Sourcefn end_with_response<'exec>(
self,
output: TResponse,
) -> StartHookResult<'exec, Self, TEndPayload, TResponse>
fn end_with_response<'exec>( self, output: TResponse, ) -> StartHookResult<'exec, Self, TEndPayload, TResponse>
End the hook execution and return a response to the client immediately, skipping the rest of the execution flow.
Sourcefn end_with_graphql_error<'exec>(
self,
error: GraphQLError,
status_code: StatusCode,
) -> StartHookResult<'exec, Self, TEndPayload, TResponse>where
TResponse: FromGraphQLErrorToResponse,
fn end_with_graphql_error<'exec>(
self,
error: GraphQLError,
status_code: StatusCode,
) -> StartHookResult<'exec, Self, TEndPayload, TResponse>where
TResponse: FromGraphQLErrorToResponse,
End the hook execution with a GraphQL error,
returning a response with the appropriate error format to the client immediately, skipping the rest of the execution flow. Read more
Sourcefn on_end<'exec, F>(
self,
f: F,
) -> StartHookResult<'exec, Self, TEndPayload, TResponse>
fn on_end<'exec, F>( self, f: F, ) -> StartHookResult<'exec, Self, TEndPayload, TResponse>
Attach a callback to be executed at the end of the hook, allowing you to manipulate the end payload or response.
This is useful when you want to execute some logic after the main execution of the hook Read more