pub struct SubgraphHttpResponse {
pub status: StatusCode,
pub headers: Arc<HeaderMap>,
pub body: Bytes,
}Fields
status: StatusCodeheaders: Arc<HeaderMap>body: BytesTrait Implementations
Sourceimpl Clone for SubgraphHttpResponse
impl Clone for SubgraphHttpResponse
Sourcefn clone(&self) -> SubgraphHttpResponse
fn clone(&self) -> SubgraphHttpResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for SubgraphHttpResponse
impl Default for SubgraphHttpResponse
Sourcefn default() -> SubgraphHttpResponse
fn default() -> SubgraphHttpResponse
Returns the “default value” for a type. Read more
Sourceimpl<'exec> EndHookPayload<SubgraphHttpResponse> for OnSubgraphHttpResponseHookPayload<'exec>
impl<'exec> EndHookPayload<SubgraphHttpResponse> for OnSubgraphHttpResponseHookPayload<'exec>
Sourcefn proceed(self) -> EndHookResult<Self, TResponse>
fn proceed(self) -> EndHookResult<Self, TResponse>
Continue with the regular flow of the hook
This is called in most cases when you don’t short-circuit the hook with a response or an error.
Sourcefn end_with_response(self, output: TResponse) -> EndHookResult<Self, TResponse>
fn end_with_response(self, output: TResponse) -> EndHookResult<Self, TResponse>
End the hook execution and return a response to the client immediately, skipping the rest of the execution flow.
Sourcefn end_with_graphql_error(
self,
error: GraphQLError,
status_code: StatusCode,
) -> EndHookResult<Self, TResponse>
fn end_with_graphql_error( self, error: GraphQLError, status_code: StatusCode, ) -> EndHookResult<Self, TResponse>
End the hook execution with a GraphQL error,
returning a response with the appropriate error format to the client immediately, skipping the rest of the execution flow. Read more
Sourceimpl FromGraphQLErrorToResponse for SubgraphHttpResponse
impl FromGraphQLErrorToResponse for SubgraphHttpResponse
fn from_graphql_error_to_response( error: GraphQLError, status: StatusCode, ) -> Self
Sourceimpl<'exec> StartHookPayload<OnSubgraphHttpResponseHookPayload<'exec>, SubgraphHttpResponse> for OnSubgraphHttpRequestHookPayload<'exec>
impl<'exec> StartHookPayload<OnSubgraphHttpResponseHookPayload<'exec>, SubgraphHttpResponse> for OnSubgraphHttpRequestHookPayload<'exec>
Sourcefn proceed<'exec>(self) -> StartHookResult<'exec, Self, TEndPayload, TResponse>
fn proceed<'exec>(self) -> StartHookResult<'exec, Self, TEndPayload, TResponse>
Continue with the regular flow of the hook
This is called in most cases when you don’t short-circuit the hook with a response or an error. Read more
Sourcefn end_with_response<'exec>(
self,
output: TResponse,
) -> StartHookResult<'exec, Self, TEndPayload, TResponse>
fn end_with_response<'exec>( self, output: TResponse, ) -> StartHookResult<'exec, Self, TEndPayload, TResponse>
End the hook execution and return a response to the client immediately, skipping the rest of the execution flow.
Sourcefn end_with_graphql_error<'exec>(
self,
error: GraphQLError,
status_code: StatusCode,
) -> StartHookResult<'exec, Self, TEndPayload, TResponse>where
TResponse: FromGraphQLErrorToResponse,
fn end_with_graphql_error<'exec>(
self,
error: GraphQLError,
status_code: StatusCode,
) -> StartHookResult<'exec, Self, TEndPayload, TResponse>where
TResponse: FromGraphQLErrorToResponse,
End the hook execution with a GraphQL error,
returning a response with the appropriate error format to the client immediately, skipping the rest of the execution flow. Read more
Sourcefn on_end<'exec, F>(
self,
f: F,
) -> StartHookResult<'exec, Self, TEndPayload, TResponse>
fn on_end<'exec, F>( self, f: F, ) -> StartHookResult<'exec, Self, TEndPayload, TResponse>
Attach a callback to be executed at the end of the hook, allowing you to manipulate the end payload or response.
This is useful when you want to execute some logic after the main execution of the hook Read more