OnHttpRequestHookPayload

Struct OnHttpRequestHookPayload 

pub struct OnHttpRequestHookPayload<'req> {
    pub router_http_request: WebRequest<DefaultError>,
    pub context: &'req PluginContext,
}

Fields

router_http_request: WebRequest<DefaultError>

The raw incoming HTTP request to the router It includes all the details of the request such as headers, body, etc.

Example:

use hive_router::{
   plugins::hooks::on_http_request::{OnHttpRequestHookPayload, OnHttpRequestHookResult},
};

fn on_http_request<'req>(mut payload: OnHttpRequestHookPayload<'req>) -> OnHttpRequestHookResult<'req> {
    let my_header = payload.router_http_request.headers().get("my-header");
    // do something with the header...
    payload.proceed()
}
context: &'req PluginContext

The context object that can be used to share data across different plugin hooks for the same request. It is unique per request and is dropped after the response is sent.

Learn more about the context data sharing in the docs

Example:

use hive_router::{
    plugins::hooks::{
        on_http_request::{OnHttpRequestHookPayload, OnHttpRequestHookResult},
        on_execute::{OnExecuteStartHookPayload, OnExecuteStartHookResult}    
    },
    plugin_context::PluginContext,
    async_trait::async_trait,
};

struct ContextData {
    greetings: String
}

#[async_trait]
impl RouterPlugin for MyPlugin {
    fn on_http_request<'req>(mut payload: OnHttpRequestHookPayload<'req>) -> OnHttpRequestHookResult<'req> {
        let context_data = ContextData {
           greetings: "Hello from context!".to_string()
        };

       payload.context.insert(context_data);

       payload.proceed()
    }

    async fn on_execute<'exec>(&'exec self, payload: OnExecuteStartHookPayload<'exec>) -> OnExecuteStartHookResult<'exec> {
        let context_data = payload.context.get::<ContextData>().unwrap();
        println!("{}", context_data.greetings); // prints "Hello from context!"
        payload.proceed()
    }
}