pub struct GraphQLParams {
pub query: Option<String>,
pub operation_name: Option<String>,
pub variables: HashMap<String, Value>,
pub extensions: Option<HashMap<String, Value>>,
}Expand description
The GraphQL parameters parsed from the HTTP request body by the router.
This includes the query, operationName, variables, and extensions
Learn more about GraphQL-over-HTTP params
Fields
query: Option<String>The GraphQL query string parsed from the HTTP request body by the router
This contains the source text of a GraphQL query, mutation, or subscription sent by the client in the request body.
It can be None if the client did not send a query string in the request body.
operation_name: Option<String>The operation name parsed from the HTTP request body by the router
This is the name of the operation that the client wants to execute, sent in the request body.
It is optional and can be None if the client did not specify an operation
variables: HashMap<String, Value>The variables map parsed from the HTTP request body by the router This is a map of variable names to their values sent by the client in the request Learn more about GraphQL variables
extensions: Option<HashMap<String, Value>>Trait Implementations
Sourceimpl Debug for GraphQLParams
impl Debug for GraphQLParams
Sourceimpl Default for GraphQLParams
impl Default for GraphQLParams
Sourcefn default() -> GraphQLParams
fn default() -> GraphQLParams
Sourceimpl<'de> Deserialize<'de> for GraphQLParams
impl<'de> Deserialize<'de> for GraphQLParams
Sourcefn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,